@@ -1,4 +1,4 @@
-# Copyright (c) 2022 Mario S. Könz; License: MIT
+# Copyright (c) 2022-2023 Mario S. Könz; License: MIT
 import dataclasses as dc
 import datetime
 import enum
@@ -9,53 +9,19 @@ from pathlib import Path
 from django.db import models
 
 from ._decorator import BACKEND_LINKER
+from ._decorator import django_model
+from ._inspect_dataclass import InspectDataclass
 from ._util import public_name
 
 __all__ = ["CreateDjangoModel", "create_django_model"]
 
 
-@dc.dataclass(frozen=True)
-class InspectDataclass:
-    dataclass: type
-
-    def extract_meta(
-        self,
-    ) -> tuple[
-        str | None,
-        list[str] | None,
-        dict[str, dict[str, tp.Any]] | None,
-        list[str] | None,
-    ]:
-        pk_key, unique_together, extra_kwgs, ordering = None, None, None, None
-        if hasattr(self.dataclass, "Meta"):
-            meta = self.dataclass.Meta  # type: ignore
-            if hasattr(meta, "primary_key"):
-                pk_key = meta.primary_key
-                assert isinstance(pk_key, str)
-            if hasattr(meta, "unique_together"):
-                unique_together = meta.unique_together
-                assert isinstance(unique_together, list)
-            if hasattr(meta, "extra"):
-                extra_kwgs = meta.extra
-                assert isinstance(extra_kwgs, dict)
-            if hasattr(meta, "ordering"):
-                ordering = meta.ordering
-                assert isinstance(ordering, list)
-
-        return pk_key, unique_together, extra_kwgs, ordering
-
-    def get_identifying_parameter(self) -> set[str]:
-        pk_key, unique_together, _, _ = self.extract_meta()
-        res = set()
-        if pk_key is not None:
-            res.add(pk_key)
-        if unique_together is not None:
-            res.update(unique_together)
-        return res
-
-
 @dc.dataclass(frozen=True)
 class CreateDjangoModel(InspectDataclass):
+    alt_field_type: "dict[str, type[models.Field[tp.Any, tp.Any]]]" = dc.field(
+        default_factory=dict
+    )
+
     def __post_init__(self) -> None:
         # evaluate the Meta class
         pk_key, unique_together, extra_kwgs, ordering = self.extract_meta()
@@ -66,15 +32,19 @@ class CreateDjangoModel(InspectDataclass):
         if self.dataclass.__str__ != object.__str__:  # type: ignore
             fields["__str__"] = self.dataclass.__str__
         fields["__module__"] = fields["Meta"].app_label
-        django_model = type(self.dataclass.__name__, (models.Model,), fields)
-        BACKEND_LINKER.link(self.dataclass, django_model)
+        dj_model = type(self.dataclass.__name__, (models.Model,), fields)
+        BACKEND_LINKER.link(self.dataclass, dj_model)
 
     def translate_fields(
         self, pk_key: str | None, extra_kwgs: dict[str, dict[str, tp.Any]] | None
     ) -> "dict[str, models.Field[tp.Any, tp.Any]]":
         fields = {}
         for field in dc.fields(self.dataclass):
-            django_field, opts = self.django_field_precursor(field.type)
+            try:
+                django_field = self.alt_field_type[field.name]
+                opts: dict[str, tp.Any] = {}
+            except KeyError:
+                django_field, opts = self.django_field_precursor(field.type)
             if field.name == pk_key:
                 opts["primary_key"] = True
                 if django_field is models.ForeignKey:
@@ -174,17 +144,11 @@ class CreateDjangoModel(InspectDataclass):
 
         raise NotImplementedError(type_)
 
-    @classmethod
-    def get_default(cls, field: dc.Field[tp.Any]) -> tp.Any:
-        if field.default != dc.MISSING:
-            assert field.default_factory is dc.MISSING
-            return field.default
-        if field.default_factory != dc.MISSING:
-            assert field.default is dc.MISSING
-            return field.default_factory
-        return None
 
-
-def create_django_model(dataclass: type) -> type:
-    CreateDjangoModel(dataclass)
-    return dataclass
+def create_django_model(
+    dataclass: type,
+    alt_field_type: "dict[str, type[models.Field[tp.Any, tp.Any]]] | None" = None,
+) -> type[models.Model]:
+    alt_field_type = alt_field_type or {}
+    CreateDjangoModel(dataclass, alt_field_type)
+    return django_model(dataclass)
