@@ -1,4 +1,4 @@
-# Copyright (c) 2022 Mario S. Könz; License: MIT
+# Copyright (c) 2022-2023 Mario S. Könz; License: MIT
 import dataclasses as dc
 import enum
 import types
@@ -20,7 +20,7 @@ class DjangoStore:
 
     def dump(self, dc_obj: tp.Any) -> tuple[models.Model, bool]:
         kwgs, m2m = self.dataclass_to_django(dc_obj)
-        identifying, defaults = self._split_of_pk(dc_obj, kwgs)
+        identifying, defaults = self._split_off_pk(dc_obj, kwgs)
         dj_obj, created = self.backend_manager(dc_obj).update_or_create(
             **identifying, defaults=defaults
         )
@@ -117,7 +117,7 @@ class DjangoStore:
         return django_model(dataclass).objects.using(self.identifier)
 
     @classmethod
-    def _split_of_pk(
+    def _split_off_pk(
         cls, dc_obj: tp.Any, kwgs: dict[str, tp.Any]
     ) -> tuple[dict[str, tp.Any], dict[str, tp.Any]]:
         ident_keys = InspectDataclass(dc_obj).get_identifying_parameter()
